@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseInstallWidgetContainer.php 2358 2009-09-26 06:17:00Z fishbone $
+ * @version    SVN: $Id: baseInstallWidgetContainer.php 3187 2010-06-06 06:35:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -46,16 +46,16 @@ class BaseInstallWidgetContainer extends BaseWidgetContainer
 			$widgetId = $this->gEnv->getCurrentWidgetId();
 			$ret = $this->_db->getWidgetInfo($widgetId, $row);
 			if ($ret){
+				$version = $row['wd_version'];		// ウィジェットのバージョン
 				if ($row['wd_initialized']){		// 初期化完了済み(再初期化禁止)
 					$this->setMsg(self::MSG_GUIDANCE, 'データの再初期化が禁止されているため、スクリプトは実行できません');
 				} else {
 					// 実行するスクリプトファイルを取得
-					$scriptFiles = $this->_doScript($request, $install);
+					$scriptFiles = $this->_doScript($request, $install, $version);
 					for ($i = 0; $i < count($scriptFiles); $i++){
 						$scriptPath = $this->gEnv->getCurrentWidgetSqlPath() . '/' . $scriptFiles[$i];
 
 						// スクリプト実行
-						//if ($this->gDb->execScriptWithConvert($scriptPath, $errors)){// 正常終了の場合
 						if ($this->gInstance->getDbManager()->execScriptWithConvert($scriptPath, $errors)){// 正常終了の場合
 							$this->setMsg(self::MSG_GUIDANCE, 'スクリプト実行完了しました(ファイル名=' . $scriptFiles[$i] . ')');
 						} else {
