@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: analyzeManager.php 3027 2010-04-13 05:15:24Z fishbone $
+ * @version    SVN: $Id: analyzeManager.php 3513 2010-08-19 05:56:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -58,6 +58,47 @@ class AnalyzeManager extends Core
 		$count = $this->db->getTotalViewCount($typeId, $serial, $contentId);
 		return $count;
 	}
+	/**
+	 * 検索キーワードログを記録
+	 *
+	 * @param string    $widgetId			ウィジェットID
+	 * @param string    $keyword			検索キーワード
+	 * @return bool							true=記録、false=記録しない
+	 */
+	function logKeyword($widgetId, $keyword)
+	{
+		// 引数エラーチェック
+		if (empty($keyword)) return false;
+		
+		// 端末タイプを判定
+		$deviceType = 0;	// 端末をPCに初期化
+		if ($this->gEnv->isMobile()){		// 携帯のとき
+			$deviceType = 1;
+		}		// スマートフォンのとき
+		
+		// クライアントIDを取得
+		$cid = '';
+		switch ($deviceType){
+			case 0:			// PC
+			case 2:			// スマートフォン
+			default:
+				$cid = $this->gAccess->getClientId();// クッキー値のクライアントID
+				break;
+			case 1:			// 携帯
+				$cid = $this->gEnv->getMobileId();	// 携帯端末ID
+				break;
+		}
+		
+		// スペース区切りの場合はワードを分割
+		// 全角英数を半角に、半角カナ全角ひらがなを全角カナに変換
+		$basicWord = $keyword;
+		if (function_exists('mb_convert_kana')) $basicWord = mb_convert_kana($basicWord, 'aKCV');
+		$basicWord = strtolower($basicWord);		// 大文字を小文字に変換
+		
+		// 検索キーワードログ書き込み
+		$this->db->writeKeywordLog($deviceType, $cid, $widgetId, $keyword, $basicWord);
+		return true;
+	}
 	/**
 	 * ブラウザのタイプを取得
 	 *
