@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_base.sql 3122 2010-05-13 01:53:39Z fishbone $
+-- * @version    SVN: $Id: create_base.sql 3369 2010-07-12 06:01:35Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -293,7 +293,7 @@ CREATE TABLE _search_word (
     sw_word              TEXT                                         NOT NULL,      -- 検索キーワード
     sw_basic_word        TEXT                                         NOT NULL,      -- 比較用基本ワード
     sw_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェットID(ファイル名)
-    sw_type              INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
+    sw_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     sw_client_id         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- PCの場合はアクセス管理用クッキー値。携帯の場合は端末ID「XX-xxxxxx」(XX=キャリアDC,AU,SB、xxxxxx=端末ID)。
     sw_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログシリアル番号
     sw_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 記録日時
@@ -364,7 +364,9 @@ CREATE TABLE _templates (
     tm_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     tm_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレートID
     tm_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    
     tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(0=デフォルトテンプレート(Joomla!v1.0)、1=Joomla!v1.5)
+    tm_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     tm_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
     tm_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレート名
     tm_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
@@ -392,6 +394,7 @@ CREATE TABLE _widgets (
     wd_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
     wd_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェット名称
     wd_type              VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- ウィジェット種別(content=コンテンツ表示)
+    wd_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     wd_version           VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- バージョン文字列
     wd_fingerprint       CHAR(32)       DEFAULT ''                    NOT NULL,      -- ソースコードレベルでウィジェットを識別するためのID
     wd_group_id          VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- ウィジェットグループ(管理用)
@@ -528,6 +531,7 @@ CREATE TABLE _page_id (
     pg_default_sub_id    VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- デフォルトのサブページID(ページID種別がページメインIDとき使用)
     pg_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス(ページID種別がページメインIDとき使用)
     pg_class             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 起動クラス名(ページID種別がページメインIDとき使用)
+    pg_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     pg_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ページ名称
     pg_description       VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 説明
     pg_priority          INT            DEFAULT 0                     NOT NULL,      -- 優先度
@@ -708,6 +712,7 @@ CREATE TABLE _menu_id (
     mn_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- メニュー名称
     mn_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
     mn_type              INT            DEFAULT 0                     NOT NULL,      -- メニュータイプ(0=単一階層、1=複数階層)
+    mn_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     mn_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート順
     PRIMARY KEY  (mn_id)
 ) TYPE=innodb;
