@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 3122 2010-05-13 01:53:39Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 3390 2010-07-17 05:00:10Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -22,7 +22,7 @@
 INSERT INTO _system_config 
 (sc_id,                          sc_value,                  sc_name) VALUES
 ('system_name',                 'Magic3',                   'システム名称'),
-('db_version',                  '2010042101',               'DBバージョン'),
+('db_version',                  '2010070901',               'DBバージョン'),
 ('server_id',                   '',                         'サーバ識別用ID'),
 ('server_url',                  '',                         'サーバURL'),
 ('default_lang',                'ja',                       'デフォルト言語'),
@@ -39,8 +39,9 @@ INSERT INTO _system_config
 ('regenerate_session_id',       '0',                        'セッションID毎回更新'),
 ('script_cache_in_browser',     '1',                        'ブラウザのスクリプトキャッシュ'),
 ('site_in_public',              '1',                        'サイト公開'),
-('site_pc_in_public',           '1',                       'PC用サイト公開'),
-('site_mobile_in_public',       '1',                       '携帯用サイト公開'),
+('site_pc_in_public',           '1',                        'PC用サイト公開'),
+('site_mobile_in_public',       '1',                        '携帯用サイト公開'),
+('site_smartphone_in_public',   '1',                        'スマートフォン用サイト公開'),
 ('site_access_exception_ip',    '',                         'サイトアクセス制御なしIP'),
 ('toppage_image_path',          '',                         '管理画面トップページ画像パス'),
 ('mobile_encoding',             'SJIS-win',                 '携帯用出力変換エンコード'),
@@ -51,6 +52,7 @@ INSERT INTO _system_config
 ('default_template',            'moyoo_blue_dog',           'PC一般画面用デフォルトテンプレート'),
 ('admin_default_template',      '_admin',                   '管理画面用デフォルトテンプレート'),
 ('mobile_default_template',     'm/default',                '携帯画面用デフォルトテンプレート'),
+('smartphone_default_template', 's/default',                'スマートフォン画面用デフォルトテンプレート'),
 ('msg_template',                '_admin',                   'メッセージ表示用テンプレート'),
 ('use_template_id_in_session',  '1',                        'セッションにテンプレートIDを保存'),
 ('head_title_format',           '$1;$1 - $2;$1 - $2 - $3;', 'HTMLヘッダタイトルフォーマット'),
@@ -65,6 +67,7 @@ INSERT INTO _system_config
 ('page_cache_lifetime',          '1440',                    '画面キャッシュの保持時間(分)'),
 ('use_connect_server',           '1',                       'ポータルサーバ接続'),
 ('default_connect_server_url',   '',                        'デフォルトの連携サーバURL'),
+('config_window_open_type',      '0',                       '設定画面のウィンドウ表示タイプ'),
 ('config_window_style',          'toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=1050,height=900',               '設定画面の表示属性'),
 ('dev_use_latest_script_lib',    '0',                       '最新JavaScriptライブラリの使用(開発用)'),
 ('google_maps_key',              '',                        'Googleマップ利用キー');
@@ -87,6 +90,7 @@ INSERT INTO _nav_item
 (103,   100,          2,        'admin_menu', 'pagedef_smartphone',  0,           '',       'スマートフォン用画面', 'スマートフォン用画面編集',       'スマートフォン用Webサイトの画面を作成します。'),
 (104,   100,          3,        'admin_menu', 'widgetlist',      0,               '',       'ウィジェット管理',     'ウィジェット管理',     'ウィジェットの管理を行います。'),
 (105,   100,          4,        'admin_menu', 'templist',        0,               '',       'テンプレート管理',     'テンプレート管理',     'テンプレートの管理を行います。'),
+(106,   100,          5,        'admin_menu', 'smenudef',        0,               '',       'メニュー管理', 'メニュー管理', 'メニュー定義を管理します。'),
 (200,   0,            1,        'admin_menu', '_login',          0,               '',       'システム運用',         '',                     ''),
 (201,   200,          0,        'admin_menu', 'userlist',        0,               '',       'ユーザ一覧',           'ユーザ一覧',           'ログイン可能なユーザを管理します。'),
 (202,   200,          1,        'admin_menu', 'loginstatus',     0,               '',       'ログイン状況',         'ログイン状況',         'ユーザのログイン状況を表示します。'),
@@ -112,27 +116,28 @@ INSERT INTO _widgets
 
 -- ページIDマスター
 INSERT INTO _page_id 
-(pg_id,          pg_type, pg_default_sub_id, pg_path,       pg_name,                        pg_description,                       pg_priority, pg_active, pg_mobile, pg_editable) VALUES
-('index',        0,       'content',         'index',       'PC用アクセスポイント',         'PC用アクセスポイント',               0,           true,      false,     true),
-('m_index',      0,       'content',         'm/index',     '携帯用アクセスポイント',       '携帯用アクセスポイント',             1,           true,      true,      true),
-('admin_index',  0,       'content',         'admin/index', '管理用アクセスポイント',       '管理用アクセスポイント',             2,           true,      false,     false),
-('connector',    0,       'content',         'connector',   'サーバ接続用アクセスポイント', 'サーバ接続用アクセスポイント',       3,           true,      false,     true),
-('front',        1,       '',                '',            'トップ専用',                   'トップ専用画面用',                   0,           true,      false,     true),
-('content',      1,       '',                '',            'コンテンツ',                   'コンテンツ画面用',                   1,           true,      false,     false),
-('shop',         1,       '',                '',            'ECショップ',                   'ECショップ画面用',                   2,           true,      false,     true),
-('shop_safe',    1,       '',                '',            'ECショップ(セキュリティ保護)', 'ECショップ(セキュリティ保護)画面用', 3,           true,      false,     true),
-('bbs',          1,       '',                '',            '掲示板',                       '掲示板画面用',                       4,           true,      false,     true),
-('blog',         1,       '',                '',            'ブログ',                       'ブログ画面用',                       5,           true,      false,     true),
-('wiki',         1,       '',                '',            'Wiki',                         'Wiki画面用',                         6,           true,      false,     true),
-('photo',        1,       '',                '',            'フォトアルバム',               'フォトアルバム画面用',               7,           true,      false,     true),
-('contact',      1,       '',                '',            'お問い合わせ',                 'お問い合わせ画面用',                 8,           true,      false,     true),
-('contact2',     1,       '',                '',            'お問い合わせ2',                'お問い合わせ画面用',                 9,           true,      false,     true),
-('contact3',     1,       '',                '',            'お問い合わせ3',                'お問い合わせ画面用',                 10,          true,      false,     true),
-('reserve',      1,       '',                '',            '予約',                         '予約画面用',                         20,          true,      false,     true),
-('search',       1,       '',                '',            '検索',                         '検索画面用',                         21,          true,      false,     true),
-('user',         1,       '',                '',            'ユーザコンテンツ',             'ユーザ作成コンテンツ用',             50,          true,      false,     true),
-('custom_admin', 1,       '',                '',            '自由編集',                     '管理用自由編集画面用',               100,         false,     false,     true),
-('test',         1,       '',                '',            'テスト用',                     'テスト用非公開画面',                 101,         false,     false,     true);
+(pg_id,          pg_type, pg_default_sub_id, pg_path,       pg_name,                            pg_description,                       pg_priority, pg_device_type, pg_active, pg_mobile, pg_editable) VALUES
+('index',        0,       'content',         'index',       'PC用アクセスポイント',             'PC用アクセスポイント',               0,           0,              true,      false,     true),
+('m_index',      0,       'content',         'm/index',     '携帯用アクセスポイント',           '携帯用アクセスポイント',             1,           1,              true,      true,      true),
+('s_index',      0,       'content',         's/index',     'スマートフォン用アクセスポイント', 'スマートフォン用アクセスポイント',   1,           2,              true,      false,     true),
+('admin_index',  0,       'content',         'admin/index', '管理用アクセスポイント',           '管理用アクセスポイント',             2,           0,              true,      false,     false),
+('connector',    0,       'content',         'connector',   'サーバ接続用アクセスポイント',     'サーバ接続用アクセスポイント',       3,           0,              true,      false,     true),
+('front',        1,       '',                '',            'トップ専用',                       'トップ専用画面用',                   0,           0,              true,      false,     true),
+('content',      1,       '',                '',            'コンテンツ',                       'コンテンツ画面用',                   1,           0,              true,      false,     false),
+('shop',         1,       '',                '',            'ECショップ',                       'ECショップ画面用',                   2,           0,              true,      false,     true),
+('shop_safe',    1,       '',                '',            'ECショップ(セキュリティ保護)',     'ECショップ(セキュリティ保護)画面用', 3,           0,              true,      false,     true),
+('bbs',          1,       '',                '',            '掲示板',                           '掲示板画面用',                       4,           0,              true,      false,     true),
+('blog',         1,       '',                '',            'ブログ',                           'ブログ画面用',                       5,           0,              true,      false,     true),
+('wiki',         1,       '',                '',            'Wiki',                             'Wiki画面用',                         6,           0,              true,      false,     true),
+('photo',        1,       '',                '',            'フォトアルバム',                   'フォトアルバム画面用',               7,           0,              true,      false,     true),
+('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 8,           0,              true,      false,     true),
+('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 9,           0,              true,      false,     true),
+('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 10,          0,              true,      false,     true),
+('reserve',      1,       '',                '',            '予約',                             '予約画面用',                         20,          0,              true,      false,     true),
+('search',       1,       '',                '',            '検索',                             '検索画面用',                         21,          0,              true,      false,     true),
+('user',         1,       '',                '',            'ユーザコンテンツ',                 'ユーザ作成コンテンツ用',             50,          0,              true,      false,     true),
+('custom_admin', 1,       '',                '',            '自由編集',                         '管理用自由編集画面用',               100,         0,              false,     false,     true),
+('test',         1,       '',                '',            'テスト用',                         'テスト用非公開画面',                 101,         0,              false,     false,     true);
 
 -- ページ情報マスター
 INSERT INTO _page_info
@@ -151,6 +156,7 @@ INSERT INTO _page_info
 ('m_index',   'bbs',       'bbs',           false),
 ('m_index',   'blog',      'blog',          false),
 ('m_index',   'wiki',      'wiki',          false),
+('s_index',   'content',   'content',       false),
 ('connector', 'content',   'content',       false);
 
 -- ページ定義マスター
@@ -180,6 +186,11 @@ INSERT INTO _site_def
 ('license_fax',          'ja',           '',               'ライセンス登録住所(FAX)'),
 ('msg_site_maintenance', 'ja',           'ただいまメンテナンス中です', 'サイトメンテナンスメッセージ');
 
+-- 多言語対応文字列マスター
+INSERT INTO _language_string
+(ls_id,                     ls_language_id, ls_value,                             ls_name) VALUES
+('msg_site_in_maintenance', 'ja',           'ただいまサイトのメンテナンス中です', 'メンテナンス中メッセージ');
+
 -- --------------------------------------------------------------------------------------------------
 -- 以下、変更の少ないデータ
 -- --------------------------------------------------------------------------------------------------
