@@ -7,7 +7,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: fckconfig.js 2908 2010-03-08 12:32:14Z fishbone $
+ * @version    SVN: $Id: fckconfig.js 3332 2010-07-03 02:12:12Z fishbone $
  * @link       http://www.magic3.org
  */
 FCKConfig.LinkBrowser = false ;
@@ -38,6 +38,7 @@ FCKConfig.Plugins.Add('Marquee', 'en,ja');// 携帯用marqueeタグ
 FCKConfig.Plugins.Add('Emoji', 'en,ja');// 携帯用絵文字タグ
 FCKConfig.Plugins.Add('MobileLink', 'en,ja');// 携帯用リンクタグ
 FCKConfig.Plugins.Add('googlemaps', 'en,ja');// Googleマップ
+FCKConfig.Plugins.Add('YouTube', 'en,ja');// YouTube
 
 // ツールバーの設定
 // PC用
@@ -51,7 +52,7 @@ FCKConfig.ToolbarSets["M3Default"] = [
 	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote'],
 	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
 	['Link','Unlink','Anchor'],
-	['Image','Flash','googlemaps','Table','Rule','Smiley','SpecialChar','PageBreak'],
+	['Image','Flash','YouTube','googlemaps','Table','Rule','Smiley','SpecialChar','PageBreak'],
 	'/',
 	['Style','FontFormat','FontName','FontSize'],
 	['TextColor','BGColor'],
