@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCheckenvWidgetContainer.php 2612 2009-12-04 07:11:09Z fishbone $
+ * @version    SVN: $Id: _installCheckenvWidgetContainer.php 3309 2010-06-29 07:47:42Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -217,6 +217,15 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 			$data = '<b><font color="red">off</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_xml", $data);
+		// gettext
+		$data = '<b><font color="green">on</font></b>';
+		$this->tmpl->addVar("_widget","config_gettext", $data);
+		if (extension_loaded('gettext')){
+			$data = '<b><font color="green">on</font></b>';
+		} else {
+			$data = '<b><font color="red">off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_gettext", $data);
 		
 		// 設定ファイルのパス
 		$data = $this->gConfig->configFilePath();
