@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCompleteWidgetContainer.php 2539 2009-11-10 08:56:00Z fishbone $
+ * @version    SVN: $Id: _installCompleteWidgetContainer.php 2834 2010-02-05 04:42:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -57,6 +57,7 @@ class _installCompleteWidgetContainer extends BaseWidgetContainer
 	{
 		$dbStatus = $request->trimValueOf('dbstatus');		// DBの状態
 		$type = $request->trimValueOf('install_type');
+		$dbStatus = $request->trimValueOf('dbstatus');		// DBの状態
 		$act = $request->trimValueOf('act');
 		if ($act == 'delinstaller'){		// インストーラを削除の場合
 			// ファイルを退避する
@@ -65,6 +66,7 @@ class _installCompleteWidgetContainer extends BaseWidgetContainer
 			// 管理者画面へ遷移
 			$this->gPage->redirectToDirectory();
 		}
+
 		// アクセス用URLを表示
 		$this->tmpl->addVar('_widget', 'url',			$this->gConfig->getSystemRootUrl());
 		$this->tmpl->addVar('_widget', 'url_admin',	$this->gConfig->getSystemRootUrl() . '/' . M3_SYSTEM_ADMIN_DIR_NAME);
@@ -72,6 +74,11 @@ class _installCompleteWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar('_widget', 'password',	'admin');		// 初期管理ユーザのパスワード
 		$this->tmpl->addVar("_widget", "db_status", $dbStatus);
 		$this->tmpl->addVar("_widget", "install_type", $type);			// インストールタイプ
+		if ($dbStatus == 'update'){			// DB更新の場合
+			$this->tmpl->addVar("_widget", "fore_task", "copyfile");			// 旧システムのファイルをコピー
+		} else {
+			$this->tmpl->addVar("_widget", "fore_task", "initother");		// その他のDB初期化
+		}
 	}
 }
 ?>
