@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installWidgetContainer.php 2834 2010-02-05 04:42:26Z fishbone $
+ * @version    SVN: $Id: _installWidgetContainer.php 3037 2010-04-16 06:22:58Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -53,7 +53,7 @@ class _installWidgetContainer extends BaseWidgetContainer
 			case 'complete';		// インストール完了
 				break;
 			case 'updatedb';		// データベースの更新
-				$task = initdb;
+				$task = 'initdb';
 				break;
 			default:
 				$task = 'top';
