@@ -8,15 +8,17 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainFilebrowseWidgetContainer.php 2235 2009-08-19 02:00:26Z fishbone $
+ * @version    SVN: $Id: admin_mainFilebrowseWidgetContainer.php 2780 2010-01-15 05:36:30Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainBrowseBaseWidgetContainer.php');
 
 class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetContainer
 {
+	private $canDeleteFile;		// ファイル削除可能かどうか
+	private $serialArray = array();		// 表示されているファイルのインデックス番号
 	const FILE_ICON_FILE = '/images/system/tree/file.png';			// ファイルアイコン
 	const FOLDER_ICON_FILE = '/images/system/tree/folder.png';		// ディレクトリアイコン
 	const PARENT_ICON_FILE = '/images/system/tree/parent.png';		// 親ディレクトリアイコン
@@ -81,18 +83,46 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 			// バッファ内容を出力
 			ob_end_flush();
 			exit(0);		// スクリプト終了
+		} else if ($act == 'delete'){			// ファイル削除のとき
+			$listedItem = explode(',', $request->trimValueOf('seriallist'));
+			$delItems = array();
+			for ($i = 0; $i < count($listedItem); $i++){
+				// 項目がチェックされているかを取得
+				$itemName = 'item' . $i . '_selected';
+				$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
+				
+				if ($itemValue){		// チェック項目
+					// 削除可能かチェック
+					$filename = $request->trimValueOf('item' . $i . '_name');
+					$filePath = $path . DIRECTORY_SEPARATOR . $filename;
+					if (is_writable($filePath) &&
+						strStartsWith($filePath, $this->gEnv->getSystemRootPath() . DIRECTORY_SEPARATOR . M3_DIR_NAME_RESOURCE . DIRECTORY_SEPARATOR)){
+						$delItems[] = $filePath;		// 削除するファイルのパス
+					} else {
+						$this->setMsg(self::MSG_USER_ERR, '削除できないファイルが含まれています。ファイル名=' . $this->convertToDispString($filename));
+						break;
+					}
+				}
+			}
+			if ($this->getMsgCount() == 0 && count($delItems) > 0){
+				$ret = true;
+				for ($i = 0; $i < count($delItems); $i++){
+					if (!unlink($delItems[$i])) $ret = false;
+				}
+				if ($ret){		// ファイル削除成功のとき
+					$this->setGuidanceMsg('ファイルを削除しました');
+				} else {
+					$this->setAppErrorMsg('ファイル削除に失敗しました');
+				}
+			}
 		}
 		
-		// ファイル一覧を作成
-		$this->createFileList($path);
-		
 		// カレントディレクトリのパスを作成
 		if ($path == $this->gEnv->getSystemRootPath()){
 			$pathLink = $this->gEnv->getSystemRootPath();
 		} else {
 			$pathLink = '<a href="#" onclick="selDir(\'' . $this->adaptWindowsPath($this->convertToDispString($this->gEnv->getSystemRootPath())) . '\');return false;">' . $this->convertToDispString($this->gEnv->getSystemRootPath()) . '</a>';
 		}
-		
 
 		$relativePath = str_replace($this->gEnv->getSystemRootPath(), '', $path);
 		$relativePath = trim($relativePath, DIRECTORY_SEPARATOR);
@@ -109,9 +139,21 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 				}
 			}
 		}
+		// ファイル削除可能かどうか(resourceディレクトリ以下のみ削除可能)
+		$this->canDeleteFile = false;
+		if ($relativePath == M3_DIR_NAME_RESOURCE || strStartsWith($relativePath, M3_DIR_NAME_RESOURCE . DIRECTORY_SEPARATOR)){
+			$this->canDeleteFile = true;
+		} else {
+			// 削除ボタンを使用可能にする
+			$this->tmpl->addVar("_widget", "del_disabled", 'disabled ');
+		}
+		
+		// ファイル一覧を作成
+		$this->createFileList($path);
 		
 		$this->tmpl->addVar('_widget', 'path', $path);// 現在のディレクトリ
 		$this->tmpl->addVar('_widget', 'path_link', $pathLink);// 現在のディレクトリ
+		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		
 		// アップロード実行用URL
 		$this->tmpl->addVar("_widget", "upload_url", $this->getUrl($this->gEnv->getDefaultAdminUrl()));
@@ -142,16 +184,21 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 				$iconTag = '<a href="#" onclick="selDir(\'' . $this->adaptWindowsPath($this->convertToDispString(dirname($path))) . '\');return false;">';
 				$iconTag .= '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 				$iconTag .= '</a>';
+				
+				$checkDisabled = 'disabled ';
 				$row = array(
 					'icon'		=> $iconTag,		// アイコン
+					'name'		=> $this->convertToDispString($file),			// ファイル名
 					'filename'    => $fileLink,			// ファイル名
 					'size'     => $size,			// ファイルサイズ
+					'check_disabled' => $checkDisabled,		// チェックボックス使用制御
 					'selected' => $selected														// 選択中かどうか
 				);
 				$this->tmpl->addVars('file_list', $row);
 				$this->tmpl->parseTemplate('file_list', 'a');
 			}
-					
+			
+			$index = 0;			// インデックス番号
 			$dir = dir($path);
 			while (($file = $dir->read()) !== false){
 				$filePath = $path . DIRECTORY_SEPARATOR . $file;
@@ -159,6 +206,7 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 				if ($file != '.' && $file != '..'){
 					$size = '';
 					$fileLink = '';
+					$checkDisabled = '';		// チェックボックス使用制御
 					if (is_dir($filePath)){			// ディレクトリのとき
 						// アイコン作成
 						$iconUrl = $this->gEnv->getRootUrl() . self::FOLDER_ICON_FILE;
@@ -168,6 +216,7 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 						$iconTag .= '</a>';
 					
 						$fileLink = '<a href="#" onclick="selDir(\'' . $this->adaptWindowsPath($this->convertToDispString($filePath)) . '\');return false;">' . $this->convertToDispString($file) . '</a>';
+						$checkDisabled = 'disabled ';		// チェックボックス使用制御
 					} else {
 						// アイコン作成
 						$iconUrl = $this->gEnv->getRootUrl() . self::FILE_ICON_FILE;
@@ -176,8 +225,11 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 						
 						$fileLink = $this->convertToDispString($file);
 						$size = filesize($filePath);
+						
+						// ファイル削除用チェックボックス
+						if (!$this->canDeleteFile || !is_writable($filePath)) $checkDisabled = 'disabled ';		// チェックボックス使用制御
 					}
-				
+		
 					// ファイルパーミッションの取得
 					$perms = fileperms($filePath);
 					$permStr = '';
@@ -213,16 +265,23 @@ class admin_mainFilebrowseWidgetContainer extends admin_mainBrowseBaseWidgetCont
 					}
 					
 					$row = array(
+						'index'		=> $index,			// インデックス番号
 						'icon'		=> $iconTag,		// アイコン
+						'name'		=> $this->convertToDispString($file),			// ファイル名
 						'filename'    	=> $fileLink,			// ファイル名
 						'size'     		=> $size,			// ファイルサイズ
 						'permission'    => $permStr,			// ファイルパーミッション
 						'date'    => $updateDate,			// 更新日時
 						'owner'    => $this->convertToDispString($owner),			// ファイル所有者
-						'group'    => $this->convertToDispString($group)			// ファイル所有グループ
+						'group'    => $this->convertToDispString($group),			// ファイル所有グループ
+						'check_disabled' => $checkDisabled,		// チェックボックス使用制御
 					);
 					$this->tmpl->addVars('file_list', $row);
 					$this->tmpl->parseTemplate('file_list', 'a');
+					
+					// インデックス番号を保存
+					$this->serialArray[] = $index;
+					$index++;
 				}
 			}
 			$dir->close();
