@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 3131 2010-05-14 07:07:41Z fishbone $
+ * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 3407 2010-07-20 05:05:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -199,6 +199,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		if ($this->menuItemType == '') $this->menuItemType = '0';		// デフォルトの項目タイプは通常リンク
 		$linkType = $request->trimValueOf('item_link_type');
 		$visible = ($request->trimValueOf('item_visible') == 'on') ? 1 : 0;		// チェックボックス
+		$linkContent = ($request->trimValueOf('item_link_content') == 'on') ? 1 : 0;		// コンテンツにリンクしてメニュー項目を表示制御するかどうか
 		$this->currentPageSubId = $request->trimValueOf('item_sub_id');			// ページサブID
 		$this->contentId = $request->trimValueOf('item_content_id');			// コンテンツID
 		$url = $request->trimValueOf('item_url');		// 決定したURL
@@ -216,7 +217,21 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
-				$ret = $this->db->addMenuItem($this->menuId, $parentId, $name, $desc, 0/*項目順は自動設定*/, $this->menuItemType, $linkType, $url, $visible, $newId);
+				// リンク先でメニューの表示制御を行う場合は、リンク先コンテンツタイプ、IDを取得
+				$linkContentType = '';		// コンテンツタイプ
+				$linkContentId = '';		// コンテンツID
+				if (!empty($linkContent)){
+					list($tmp, $queryStr) = explode('?', $url, 2);
+					if (!empty($queryStr)){
+						parse_str($queryStr, $params);
+						if (isset($params[M3_REQUEST_PARAM_CONTENT_ID]) || isset($params[M3_REQUEST_PARAM_CONTENT_ID_SHORT])){
+							$linkContentType = M3_VIEW_TYPE_CONTENT;		// 汎用コンテンツ
+							$linkContentId = isset($params[M3_REQUEST_PARAM_CONTENT_ID]) ? $params[M3_REQUEST_PARAM_CONTENT_ID] : $params[M3_REQUEST_PARAM_CONTENT_ID_SHORT];
+						}
+					}
+				}
+				
+				$ret = $this->db->addMenuItem($this->menuId, $parentId, $name, $desc, 0/*項目順は自動設定*/, $this->menuItemType, $linkType, $url, $visible, $newId, $linkContentType, $linkContentId);
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
 					$this->serialNo = $newId;		// メニュー項目IDを更新
@@ -232,7 +247,21 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
-				$ret = $this->db->updateMenuItem($this->serialNo, $name, $desc, $this->menuItemType, $linkType, $url, $visible);
+				// リンク先でメニューの表示制御を行う場合は、リンク先コンテンツタイプ、IDを取得
+				$linkContentType = '';		// コンテンツタイプ
+				$linkContentId = '';		// コンテンツID
+				if (!empty($linkContent)){
+					list($tmp, $queryStr) = explode('?', $url, 2);
+					if (!empty($queryStr)){
+						parse_str($queryStr, $params);
+						if (isset($params[M3_REQUEST_PARAM_CONTENT_ID]) || isset($params[M3_REQUEST_PARAM_CONTENT_ID_SHORT])){
+							$linkContentType = M3_VIEW_TYPE_CONTENT;		// 汎用コンテンツ
+							$linkContentId = isset($params[M3_REQUEST_PARAM_CONTENT_ID]) ? $params[M3_REQUEST_PARAM_CONTENT_ID] : $params[M3_REQUEST_PARAM_CONTENT_ID_SHORT];
+						}
+					}
+				}
+				
+				$ret = $this->db->updateMenuItem($this->serialNo, $name, $desc, $this->menuItemType, $linkType, $url, $visible, $linkContentType, $linkContentId);
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
 					
@@ -268,6 +297,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 				$name = '';		// 名前
 				$linkType = 0;	// リンクタイプ
 				$visible = 1;
+				$linkContent = 0;		// コンテンツにリンクしてメニュー項目を表示制御するかどうか
 				$url = '';	// リンク先			
 			} else {
 				$ret = $this->db->getMenuItem($this->serialNo, $row);
@@ -290,6 +320,9 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 						$ret = $this->gEnv->parseUrl($testUrl, $pageId, $pageSubId, $paramArray);
 						if (!$ret) $this->currentPageSubId = '_other';		// 他サイトへのリンクのとき
 					}
+					// コンテンツにリンクしてメニュー項目を表示制御するかどうか
+					$linkContent = 0;
+					if (!empty($row['md_content_type'])) $linkContent = 1;			// リンクコンテンツが設定されている場合はメニューの表示制御を行う
 				}
 			}
 		}
@@ -405,6 +438,9 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$visibleStr = '';
 		if ($visible) $visibleStr = 'checked';
 		$this->tmpl->addVar("_widget", "sel_item_visible", $visibleStr);
+		$checked = '';
+		if (!empty($linkContent)) $checked = 'checked';
+		$this->tmpl->addVar("_widget", "link_content", $checked);
 		
 		// 選択中のシリアル番号、IDを設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
