@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: bbs_2ch_mainTopWidgetContainer.php 2816 2010-01-29 05:56:05Z fishbone $
+ * @version    SVN: $Id: bbs_2ch_mainTopWidgetContainer.php 3365 2010-07-10 07:13:30Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/bbs_2ch_mainBaseWidgetContainer.php');
@@ -29,6 +29,7 @@ class bbs_2ch_mainTopWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 	private $nameColor;		// 登録者名文字色
 	private $createEmailLink;	// Eメールのリンクを作成するかどうか
 	private $isExistsMessage;	// メッセージが存在するかどうか
+	private $ticket;		// POST確認用ハッシュキー
 	const DEFAULT_MENU_NAME = 'menu';		// スレッドメニューの名前
 	
 	/**
@@ -66,37 +67,44 @@ class bbs_2ch_mainTopWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		$act = $request->trimValueOf('act');
+		$postTicket = $request->trimValueOf('ticket');		// POST確認用
 		$threadId = $request->trimValueOf(M3_REQUEST_PARAM_BBS_THREAD_ID);	// スレッドID
 		$message = $request->valueOf('bbs_message');// 投稿メッセージ
 		$name = $request->trimValueOf('bbs_name');// 名前
 		$email = $request->trimValueOf('bbs_email');// Eメールアドレス
 		
 		if ($act == 'add'){		// 投稿追加のとき
-			// 入力項目のエラーチェック
-			$this->checkMessageInput($this->_boardId, $threadId, $name, $email, $message);
+			if (!empty($postTicket) && $postTicket == $request->getSessionValue(M3_SESSION_POST_TICKET)){		// 正常なPOST値のとき
+				// 入力項目のエラーチェック
+				$this->checkMessageInput($this->_boardId, $threadId, $name, $email, $message);
 			
-			// エラーなしの場合は、データを更新
-			if ($this->getMsgCount() == 0){
-				// 新規投稿文の追加
-				$updateDt = true;		// 日付を更新
-				$ret = $this->_db->addMessage($this->_boardId, $threadId, $name, $email, $message, $updateDt);
+				// エラーなしの場合は、データを更新
+				if ($this->getMsgCount() == 0){
+					// 新規投稿文の追加
+					$updateDt = true;		// 日付を更新
+					$ret = $this->_db->addMessage($this->_boardId, $threadId, $name, $email, $message, $updateDt);
 
-				if ($ret){		// データ追加成功のとき
-					//$this->setMsg(self::MSG_GUIDANCE, 'スレッドを作成しました');
-					$this->setMsg(self::MSG_GUIDANCE, '書きこみが終わりました。');
+					if ($ret){		// データ追加成功のとき
+						//$this->setMsg(self::MSG_GUIDANCE, 'スレッドを作成しました');
+						$this->setMsg(self::MSG_GUIDANCE, '書きこみが終わりました。');
 					
-					// 入力項目を使用不可に設定
-					$this->tmpl->addVar("_widget", "name_disabled", 'disabled ');
-					$this->tmpl->addVar("_widget", "email_disabled", 'disabled ');
-					$this->tmpl->addVar("_widget", "subject_disabled", 'disabled ');
-					$this->tmpl->addVar("_widget", "message_disabled", 'disabled ');
-					$this->tmpl->addVar("_widget", "button_disabled", 'disabled ');
-				} else {
-					//$this->setMsg(self::MSG_APP_ERR, 'スレッドを作成に失敗しました');
-					$this->setMsg(self::MSG_APP_ERR, '書きこみに失敗しました。');
+						// 入力項目を使用不可に設定
+						$this->tmpl->addVar("_widget", "name_disabled", 'disabled ');
+						$this->tmpl->addVar("_widget", "email_disabled", 'disabled ');
+						$this->tmpl->addVar("_widget", "subject_disabled", 'disabled ');
+						$this->tmpl->addVar("_widget", "message_disabled", 'disabled ');
+						$this->tmpl->addVar("_widget", "button_disabled", 'disabled ');
+					} else {
+						//$this->setMsg(self::MSG_APP_ERR, 'スレッドを作成に失敗しました');
+						$this->setMsg(self::MSG_APP_ERR, '書きこみに失敗しました。');
+					}
 				}
 			}
+			$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 		}
+		// ハッシュキー作成
+		$this->ticket = md5(time() . $this->gAccess->getAccessLogSerialNo());
+		$request->setSessionValue(M3_SESSION_POST_TICKET, $this->ticket);		// セッションに保存
 		
 		// 表示スタイル作成
 		$this->createEmailLink = $this->_configArray[self::CF_SHOW_EMAIL];		// Eメールのリンクを作成するかどうか
@@ -285,7 +293,8 @@ class bbs_2ch_mainTopWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 				'thread_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($threadUrl, true)),				// スレッド全表示URL
 				'thread50_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($thread50Url, true)),				// スレッド最新50表示URL
 				'thread100_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($thread100Url, true)),				// スレッド100まで表示URL
-				'reload_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($reloadUrl, true))					// 画面再表示
+				'reload_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($reloadUrl, true)),					// 画面再表示
+				'ticket'		=> $this->ticket		// POST確認用ハッシュキー
 			);
 			$this->tmpl->addVars('thread_list', $row);
 			$this->tmpl->parseTemplate('thread_list', 'a');
