@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainConfigWidgetContainer.php 1453 2009-01-19 08:40:44Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainConfigWidgetContainer.php 2231 2009-08-17 03:13:16Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_blog_mainBaseWidgetContainer.php');
@@ -61,9 +61,7 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		
-		$defaultLang	= $gEnvManager->getDefaultLanguage();
+		$defaultLang	= $this->gEnv->getDefaultLanguage();
 		
 		$act = $request->trimValueOf('act');
 		$entryViewCount = $request->trimValueOf('entry_view_count');		// 記事表示数
