@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainWidgetContainer.php 3443 2010-07-30 07:47:09Z fishbone $
+ * @version    SVN: $Id: blog_mainWidgetContainer.php 3454 2010-08-06 02:57:16Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -475,7 +475,7 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		
 		// 記事へのリンクを生成
 		//$linkUrl = $this->currentPageUrl . '&entryid=' . $entryId;
-		$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_BLOG_ID . '=' . $entryId, true/*リンク用*/);
+		$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $entryId, true/*リンク用*/);
 		$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >コメント(' . $commentCount . ')</a>';
 		
 		// HTMLを出力(出力内容は特にエラーチェックしない)
@@ -541,7 +541,7 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		
 		// 記事へのリンクを生成
 		//$linkUrl = $this->currentPageUrl . '&entryid=' . $fetchedRow['be_id'];
-		$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_BLOG_ID . '=' . $fetchedRow['be_id'], true/*リンク用*/);
+		$linkUrl = $this->getUrl($this->gEnv->getDefaultUrl() . '?'. M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $fetchedRow['be_id'], true/*リンク用*/);
 		$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >' . $title . '</a>';
 		
 		// 日付
