@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_new_boxWidgetContainer.php 3432 2010-07-27 09:05:17Z fishbone $
+ * @version    SVN: $Id: blog_new_boxWidgetContainer.php 3455 2010-08-06 02:58:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -152,7 +152,7 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 		}
 		
 		// 記事へのリンク
-		$url = $this->defaultUrl . '?'. M3_REQUEST_PARAM_BLOG_ID . '=' . $fetchedRow['be_id'];
+		$url = $this->defaultUrl . '?'. M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $fetchedRow['be_id'];
 
 		$row = array(
 			'link_url' => $this->convertUrlToHtmlEntity($this->getUrl($url, true/*リンク用*/)),		// リンク
