@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: custom_searchWidgetContainer.php 3058 2010-04-23 05:41:13Z fishbone $
+ * @version    SVN: $Id: custom_searchWidgetContainer.php 3514 2010-08-19 05:56:29Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -111,6 +111,7 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 		if ($act == self::DEFAULT_SEARCH_ACT){		// 検索実行
 			// 検索キーワードが空以外の場合は、キーワードログを残す
 			if (!empty($keyword)){
+				/*
 				// スペース区切りの場合はワードを分割
 								
 				// 全角英数を半角に、半角カナ全角ひらがなを全角カナに変換
@@ -121,6 +122,9 @@ class custom_searchWidgetContainer extends BaseWidgetContainer
 				// 検索キーワードログ書き込み
 				$cid = $this->gAccess->getClientId();// クッキー値のクライアントID
 				$this->db->writeKeywordLog($cid, $this->gEnv->getCurrentWidgetId(), $keyword, $basicWord);
+				*/
+				// 検索キーワードを記録
+				$this->gInstance->getAnalyzeManager()->logKeyword($this->gEnv->getCurrentWidgetId(), $keyword);
 			}
 			
 			// カテゴリの設定値を取得
