@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: custom_searchDb.php 3071 2010-04-26 07:27:00Z fishbone $
+ * @version    SVN: $Id: custom_searchDb.php 3514 2010-08-19 05:56:29Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -80,7 +80,7 @@ class custom_searchDb extends BaseDb
 	 * @param string $basicWord		比較用基本ワード
 	 * @return bool					true=ログ出力完了、false=失敗
 	 */
-	function writeKeywordLog($cid, $widgetId, $keyword, $basicWord)
+	/*function writeKeywordLog($cid, $widgetId, $keyword, $basicWord)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$logSerial = $this->gEnv->getCurrentAccessLogSerial();	// 現在のアクセスログシリアル番号
@@ -97,7 +97,7 @@ class custom_searchDb extends BaseDb
 
 		// トランザクション終了
 		return $this->endTransaction();
-	}
+	}*/
 	/**
 	 * コンテンツを検索(表示用)
 	 *
