@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 2912 2010-03-09 08:38:18Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 3442 2010-07-30 07:46:54Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -265,7 +265,7 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 			$iconUrl = $this->gEnv->getRootUrl() . self::EDIT_ICON_FILE;		// 編集アイコン
 			$iconTitle = '編集';
 			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-			$buttonList = '<span style="line-height:0;"><a href="#" onclick="editContent(' . $fetchedRow['cn_id'] . ');">' . $editImg . '</a></span><br />';
+			$buttonList = '<span style="line-height:0;"><a href="javascript:void(0);" onclick="editContent(' . $fetchedRow['cn_id'] . ');">' . $editImg . '</a></span><br />';
 			$buttonList = '<div style="text-align:right;position:absolute;top:10px;z-index:10;width:100%;">' . $buttonList . '</div>';
 		}
 		
