@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id$
+ * @version    SVN: $Id: admin_ec_mainStockWidgetContainer.php 2260 2009-08-27 05:59:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -37,8 +37,6 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -47,7 +45,7 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->productDb = new productDb();
 		
 		// EC用共通オブジェクト取得
-		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
+		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
 		$this->ecObj->initByDefault();		// デフォルト値で初期化
 	}
 	/**
@@ -62,8 +60,6 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{
-		global $gEnvManager;
-		
 		return 'admin_stock.tmpl.html';
 	}
 	/**
@@ -77,11 +73,9 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-
 		// ユーザ情報、表示言語
-		$userId		= $gEnvManager->getCurrentUserId();
-		$defaultLangId	= $gEnvManager->getDefaultLanguage();
+		$userId		= $this->gEnv->getCurrentUserId();
+		$defaultLangId	= $this->gEnv->getDefaultLanguage();
 		
 		// 日付作成
 		$this->today = date("Y/m/d");	// 今日
@@ -121,12 +115,12 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$pageLink = '';
 		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
 			for ($i = 1; $i <= $pageCount; $i++){
-				$linkUrl = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
-				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=productlist&keyword=' . $keyword . '&category=' . $this->search_categoryId . '&page=' . $i;
+				$linkUrl = $this->gEnv->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId() . '&task=productlist&keyword=' . $keyword . '&category=' . $this->search_categoryId . '&page=' . $i;
 				if ($i == $pageNo){
 					$link = '&nbsp;' . $i;
 				} else {
-					$link = '&nbsp;<a href="' . $linkUrl . '" >' . $i . '</a>';
+					$link = '&nbsp;<a href="' . $this->getUrl($linkUrl, true) . '" >' . $i . '</a>';
 				}
 				$pageLink .= $link;
 			}
@@ -149,9 +143,8 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		
 			
 		// パスの設定
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());
-		$this->tmpl->addVar('_widget', 'widget_id', $gEnvManager->getCurrentWidgetId());
+		$this->tmpl->addVar("_widget", "admin_url", $this->getUrl($this->gEnv->getDefaultAdminUrl()));
+		$this->tmpl->addVar('_widget', 'widget_id', $this->gEnv->getCurrentWidgetId());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -163,13 +156,11 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function productListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		// 行カラーの設定
-		$lineColor = '';
+		/*$lineColor = '';
 		if ($index % 2 != 0){
 			$lineColor = 'class="even"';		// 偶数行
-		}
+		}*/
 		
 		// データ再取得
 		$ret = $this->productDb->getProductBySerial($fetchedRow['pt_serial'], $row, $row2, $row3, $row4, $row5);
@@ -266,7 +257,7 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			$stockCount30Str = $stockCount30;
 		}
 		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
+			//'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['pt_serial']),	// シリアル番号
 			'id' => $productId,			// ID
@@ -311,8 +302,6 @@ class admin_ec_mainStockWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function categoryLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['pc_id'] == $this->search_categoryId){
 			$selected = 'selected';
