@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainChangepwdWidgetContainer.php 191 2008-02-13 11:15:58Z naoki $
+ * @version    SVN: $Id: ec_mainChangepwdWidgetContainer.php 2081 2009-07-10 07:17:02Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -29,14 +29,12 @@ class ec_mainChangepwdWidgetContainer extends BaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DB接続オブジェクト作成
 		$this->mainDb = new ec_mainDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -63,15 +61,12 @@ class ec_mainChangepwdWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gMailManager;
-		
 		$act = $request->trimValueOf('act');
 		$password = $request->trimValueOf('password');
 		$length = $request->trimValueOf('length');		// パスワード長
 		if ($act == 'update'){			// パスワード更新のとき
 			// パスワード変更
-			$ret = $this->sysDb->updateLoginUserPassword($gEnvManager->getCurrentUserId(), $password, true/*MD5化されているパスワード*/);
+			$ret = $this->sysDb->updateLoginUserPassword($this->gEnv->getCurrentUserId(), $password, true/*MD5化されているパスワード*/);
 			if ($ret){
 				$this->tmpl->addVar("_widget", "message", 'パスワード変更が完了しました');
 				$this->tmpl->addVar("_widget", "button_disabled", 'disabled');		// ボタン使用不可
@@ -84,9 +79,7 @@ class ec_mainChangepwdWidgetContainer extends BaseWidgetContainer
 			}
 		}
 		$this->tmpl->addVar("_widget", "button_label", 'パスワード変更');		// ボタンのラベル
-		
-		// ディレクトリを設定
-		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
+		$this->tmpl->addVar("_widget", "class", $this->gDesign->getDefaultContentHeadClassString());		// コンテンツヘッダ用CSSクラス
 	}
 }
 ?>
