@@ -8,15 +8,15 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_product_displayWidgetContainer.php 867 2008-07-28 09:04:54Z fishbone $
+ * @version    SVN: $Id: admin_ec_product_displayWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_product_displayDb.php');
 
-class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
+class admin_ec_product_displayWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $sysDb;	// DB接続オブジェクト
@@ -37,14 +37,12 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DBオブジェクト作成
 		$this->db = new ec_product_displayDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -71,13 +69,10 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-
 		// ユーザ情報、表示言語
-		$userInfo		= $gEnvManager->getCurrentUserInfo();
-		$this->langId	= $gEnvManager->getDefaultLanguage();
-		$defaultLangName = $gEnvManager->getDefaultLanguageNameByCurrentLanguage();// デフォルト言語の現在の表示名を取得
+		$userInfo		= $this->gEnv->getCurrentUserInfo();
+		$this->langId	= $this->gEnv->getDefaultLanguage();
+		$defaultLangName = $this->gEnv->getDefaultLanguageNameByCurrentLanguage();// デフォルト言語の現在の表示名を取得
 
 		// デフォルト値設定
 		$this->selType = 0;			// 現在の表題
@@ -209,7 +204,7 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 			$this->paramObj[$this->selType]->subList = $this->currentSubList;
 			$ret = $this->updateWidgetParamObj($this->paramObj);
 			if (!$ret) $this->setMsg(self::MSG_APP_ERR, '追加に失敗しました');
-			$gPageManager->updateParentWindow();// 親ウィンドウを更新
+			$this->gPage->updateParentWindow();// 親ウィンドウを更新
 		} else if ($act == 'updatelist'){	// おすすめリストを更新のとき
 			for ($i = 0; $i < count($this->currentSubList); $i++){
 				$itemName = 'item' . $i . '_view_index';
@@ -234,7 +229,7 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$this->gPage->updateParentWindow();// 親ウィンドウを更新
 			}
 		} else if ($act == 'deleteline'){	// おすすめリスト項目削除のとき
 			// おすすめ項目を削除
@@ -251,7 +246,7 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 			} else {
 				$this->setMsg(self::MSG_APP_ERR, '項目削除に失敗しました');
 			}
-			$gPageManager->updateParentWindow();// 親ウィンドウを更新
+			$this->gPage->updateParentWindow();// 親ウィンドウを更新
 		} else if ($act == 'update'){		// 設定更新のとき
 			// 入力値を取得
 			$title	= $request->trimValueOf('item_title');			// ヘッダタイトル
@@ -287,11 +282,11 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$this->gPage->updateParentWindow();// 親ウィンドウを更新
 			}
 		} else if ($act == 'seldisplaytype'){		// 表示タイプを選択
 			// 定義IDを更新
-			$ret = $this->sysDb->updateWidgetConfigId($gEnvManager->getCurrentWidgetId(), $defSerial, $this->selType, $title);
+			$ret = $this->sysDb->updateWidgetConfigId($this->gEnv->getCurrentWidgetId(), $defSerial, $this->selType, $title);
 			if ($ret){
 				$message = '設定を「' . $title . '」に変更しました';
 				$this->setMsg(self::MSG_GUIDANCE, $message);
@@ -299,7 +294,7 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 				$message = '設定「' . $title . '」の変更に失敗しました';
 				$this->setMsg(self::MSG_APP_ERR, $message);
 			}
-			$gPageManager->updateParentWindow();// 親ウィンドウを更新
+			$this->gPage->updateParentWindow();// 親ウィンドウを更新
 		} else {		// 初期表示の場合
 			// 入力値初期化
 		}
@@ -339,10 +334,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 		if ($descVisible) $this->tmpl->addVar('_widget', 'DESC_VISIBLE',	'checked');			// 商品説明表示
 		if ($imgVisible) $this->tmpl->addVar('_widget', 'IMG_VISIBLE',	'checked');			// 商品画像表示
 		if ($detailVisible) $this->tmpl->addVar('_widget', 'DETAIL_VISIBLE',	'checked');			// 詳細ボタン表示
-		
-		// パスの設定
-		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -354,13 +345,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 	 */
 	function productListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
 		// 項目選択のラジオボタンの状態
 		$id = $this->convertToDispString($fetchedRow['pt_id']);
 		
@@ -370,7 +354,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 		}
 		$row = array(
 			'index' => $index,											// 項目インデックス
-			'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['pt_serial']),	// シリアル番号
 			'id' => $id,			// ID
@@ -400,11 +383,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 			$subObj = $this->currentSubList[$i];
 			$id = $subObj->id;
 			
-			// 行カラーの設定
-			$lineColor = '';
-			if ($i % 2 != 0){
-				$lineColor = 'class="even"';		// 偶数行
-			}
 			// 商品情報を取得
 			$ret = $this->db->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4);
 			if ($ret){
@@ -417,7 +395,6 @@ class admin_ec_product_displayWidgetContainer extends BaseWidgetContainer
 			$row = array(
 				'no' => $i + 1,											// 項目番号
 				'index' => $i,											// 項目インデックス
-				'line_color' => $lineColor,											// 行のカラー
 				'id' => $id,			// ID
 				'name' => $name,		// 名前
 				'code' => $this->convertToDispString($row['pt_code']),		// 商品コード
