@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_blogReadWidgetContainer.php 3469 2010-08-12 04:06:33Z fishbone $
+ * @version    SVN: $Id: m_blogReadWidgetContainer.php 3512 2010-08-19 05:31:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/m_blogBaseWidgetContainer.php');
@@ -21,7 +21,7 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 	private $isExistsMessage;	// メッセージが存在するかどうか
 	private $isExistsNextPage;	// 次のページがあるかどうか
 	private $pageTitle;				// 画面タイトル、パンくずリスト用タイトル
-	const DEFAULT_VIEW_COUNT	= 3;				// デフォルトの表示記事数
+	const DEFAULT_SEARCH_COUNT	= 5;				// デフォルトの検索記事数
 	
 	/**
 	 * コンストラクタ
@@ -78,11 +78,61 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 		$year = $request->trimValueOf('year');		// 年指定
 		$month = $request->trimValueOf('month');		// 月指定
 		$day = $request->trimValueOf('day');		// 日指定
-		$keyword = $request->trimValueOf('keyword');// 検索キーワード
+		//$keyword = $request->trimValueOf('keyword');// 検索キーワード
+		$keyword = $request->mobileTrimValueOf('keyword');// 検索キーワード
 		$category = $request->trimValueOf('category');		// カテゴリー
-		
+
 		$showDefault = false;			// デフォルト状態での表示
-		if ($act == 'view'){			// 記事を表示のとき
+		if ($act == 'search'){			// 検索
+			// キーワード検索のとき
+			if (empty($keyword)){
+				$message = '検索キーワードが入力されていません';
+			} else {
+				// 検索項目数
+				$searchCount = self::DEFAULT_SEARCH_COUNT;		// 検索記事数
+				
+				// 検索キーワードを記録
+				$this->gInstance->getAnalyzeManager()->logKeyword($this->gEnv->getCurrentWidgetId(), $keyword);
+				
+				/*
+				// 検索キーワードログを残す
+				// スペース区切りの場合はワードを分割
+								
+				// 全角英数を半角に、半角カナ全角ひらがなを全角カナに変換
+				$basicWord = $keyword;
+				if (function_exists('mb_convert_kana')) $basicWord = mb_convert_kana($basicWord, 'aKCV');
+				$basicWord = strtolower($basicWord);		// 大文字を小文字に変換
+				
+				// 検索キーワードログ書き込み
+				$cid = $this->gAccess->getClientId();// クッキー値のクライアントID
+				//$this->db->writeKeywordLog($cid, $this->gEnv->getCurrentWidgetId(), $keyword, $basicWord);
+				*/
+				
+				// 総数を取得
+				$totalCount = $this->_db->searchEntryItemsCountByKeyword($now, $keyword, $this->langId);
+
+				// リンク文字列作成、ページ番号調整
+				$convKeyword = $request->convMobileText($keyword);		// 検索キーワードを携帯用のコードへ変換
+				$pageLink = $this->createPageLink($pageNo, $totalCount, $searchCount, $this->_currentPageUrl . '&act=search&keyword=' . urlencode($convKeyword));
+				
+				// 記事一覧を表示
+				$this->_db->searchEntryItemsByKeyword($searchCount, $pageNo, $now, $keyword, $this->langId, array($this, 'searchItemsLoop'));
+				
+				if ($this->isExistsViewData){
+					// ページリンクを埋め込む
+					if (!empty($pageLink)){
+						$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+						$this->tmpl->addVar("page_link", "page_link", $pageLink);
+					}
+					$message = self::MESSAGE_SEARCH_KEYWORD . $keyword;
+				} else {	// 検索結果なしの場合
+					$this->tmpl->setAttribute('entrylist', 'visibility', 'hidden');
+					$message = self::MESSAGE_FIND_NO_ENTRY;
+				}
+			}
+			$this->setGuidanceMsg($message);			// ユーザ向けメッセージ
+			$this->pageTitle = self::DEFAULT_TITLE_SEARCH;		// 画面タイトル、パンくずリスト用タイトル
+		} else if ($act == 'view'){			// 記事を表示のとき
 			// コメントを受け付けるときは、コメント入力欄を表示
 			// ***** 記事を表示する前に呼び出す必要あり *****
 			/*if (!empty($receiveComment)){
@@ -327,6 +377,47 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 		$this->isExistsViewData = true;				// 表示データがあるかどうか
 		return true;
 	}
+	/**
+	 * 取得したコンテンツ項目をテンプレートに設定する
+	 *
+	 * @param int		$index			行番号
+	 * @param array		$fetchedRow		取得行
+	 * @param object	$param			任意使用パラメータ
+	 * @return bool						trueを返すとループ続行。falseを返すとその時点で終了。
+	 */
+	function searchItemsLoop($index, $fetchedRow)
+	{
+		$entryId = $fetchedRow['be_id'];// 記事ID
+		$title = $fetchedRow['be_name'];// タイトル
+		$date = $fetchedRow['be_regist_dt'];// 日付
+		
+		// 記事へのリンクを生成
+		$linkUrl = $this->getUrl($this->gEnv->getDefaultMobileUrl() . '?'. M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $entryId, true/*リンク用*/);
+		$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >' . $title . '</a>';
+
+		// テキストに変換。HTMLタグ削除。
+		$entryText = $this->gInstance->getTextConvManager()->htmlToText($fetchedRow['be_html']);
+
+		// 検索結果用にテキストを詰める。改行、タブ、スペース削除。
+		$entryText = str_replace(array("\r", "\n", "\t", " "), '', $entryText);
+
+		// 文字列長を修正
+		if (function_exists('mb_strimwidth')){
+			$entryText = mb_strimwidth($entryText, 0, self::SEARCH_BODY_SIZE, '…');
+		} else {
+			$entryText = substr($entryText, 0, self::SEARCH_BODY_SIZE) . '...';
+		}
+
+		$row = array(
+			'title' => $link,			// リンク付きタイトル
+			'date' => $date,			// 日付
+			'entry' => $entryText	// 投稿記事
+		);
+		$this->tmpl->addVars('entrylist', $row);
+		$this->tmpl->parseTemplate('entrylist', 'a');
+		$this->isExistsViewData = true;				// 表示データがあるかどうか
+		return true;
+	}
 	/**
 	 * ページリンク作成
 	 *
