@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ls2.inc.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @version    SVN: $Id: ls2.inc.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 /*
@@ -75,7 +75,6 @@ function plugin_ls2_convert()
 	if ($prefix == '') $prefix = strip_bracket($vars['page']) . '/';
 
 	// fixed by naoki on 2008/9/30
-	//array_walk($args, 'plugin_ls2_check_arg', & $params);
 	array_walk($args, 'plugin_ls2_check_arg', $params);
 
 	$title = (! empty($params['_args'])) ? join(',', $params['_args']) :   // Manual
@@ -175,8 +174,8 @@ function plugin_ls2_list_push(& $params, $level)
 {
 	global $_ul_left_margin, $_ul_margin, $_list_pad_str;
 
-	$result = & $params['result'];
-	$saved  = & $params['saved'];
+	$result = $params['result'];
+	$saved  = $params['saved'];
 	$cont   = TRUE;
 	$open   = '<ul%s>';
 	$close  = '</li></ul>';
